| Title: | 'Rcpp' Package Illustrating Header-Only Access to 'NLopt' |
|---|---|
| Description: | An example package which shows use of 'NLopt' functionality from C++ via 'Rcpp' without requiring linking, and relying just on 'nloptr' thanks to the exporting API added there by Jelmer Ypma. This package is a fully functioning, updated, and expanded version of the initial example by Julien Chiquet at <https://github.com/jchiquet/RcppArmadilloNLoptExample> also containing a large earlier pull request of mine. |
| Authors: | Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>) |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.2.1 |
| Built: | 2026-05-27 07:39:22 UTC |
| Source: | https://github.com/eddelbuettel/rcppnloptexample |
Helper function to access the NLopt version as an integer vector.
nloptVersion()nloptVersion()
Am integer vector with three elements for major, minor and patch release.
nloptVersion() package_version(paste(as.character(nloptVersion()), collapse="."))nloptVersion() package_version(paste(as.character(nloptVersion()), collapse="."))
A simple example for for NLopt integration for Rcpp, using an example from the NLopt tutorial.
testConstrainedProblem(method = "MMA", verbose = FALSE)testConstrainedProblem(method = "MMA", verbose = FALSE)
method |
A string defaulting to ‘MMA’ (also allowing ‘COBYLA’) which selects the algorithm use. |
verbose |
A boolean toggle defaulting to ‘false’ |
A numeric vector with two elements
https://nlopt.readthedocs.io/en/latest/NLopt_Tutorial/
testConstrainedProblem("MMA", TRUE)testConstrainedProblem("MMA", TRUE)